@@ -1,7 +1,7 @@
 // drumkv1.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -37,6 +37,7 @@
 #include "drumkv1_config.h"
 #include "drumkv1_controls.h"
 #include "drumkv1_programs.h"
+#include "drumkv1_tuning.h"
 
 #include "drumkv1_sched.h"
 
@@ -138,9 +139,14 @@ inline float drumkv1_pow2f ( const float x )
 
 // convert note to frequency (hertz)
 
-inline float drumkv1_freq ( float note )
+inline float drumkv1_freq2 ( float delta )
 {
-	return (440.0f / 32.0f) * ::powf(2.0f, (note - 9.0f) / 12.0f);
+	return ::powf(2.0f, delta / 12.0f);
+}
+
+inline float drumkv1_freq ( int note )
+{
+	return (440.0f / 32.0f) * drumkv1_freq2(float(note - 9));
 }
 
 
@@ -843,6 +849,8 @@ public:
 	drumkv1_controls *controls();
 	drumkv1_programs *programs();
 
+	void updateTuning();
+
 	void process_midi(uint8_t *data, uint32_t size);
 	void process(float **ins, float **outs, uint32_t nframes);
 
@@ -902,6 +910,8 @@ private:
 	float    m_srate;
 	float    m_bpm;
 
+	float    m_freqs[MAX_NOTES];
+
 	drumkv1_ctl m_ctl;
 
 	drumkv1_def m_def;
@@ -993,6 +1003,9 @@ drumkv1_impl::drumkv1_impl (
 	// compressors none yet
 	m_comp = NULL;
 
+	// Micro-tuning support, if any...
+	updateTuning();
+
 	// load controllers & programs database...
 	m_config.loadControls(&m_controls);
 	m_config.loadPrograms(&m_programs);
@@ -1476,7 +1489,7 @@ void drumkv1_impl::process_midi ( uint8_t *data, uint32_t size )
 				// velocity
 				const float vel = float(value) / 127.0f;
 				// quadratic velocity law
-				pv->vel  = drumkv1_velocity(vel * vel, *m_def.velocity);
+				pv->vel = drumkv1_velocity(vel * vel, *m_def.velocity);
 				// pressure/aftertouch
 				pv->pre = 0.0f;
 				pv->dca1_pre.reset(
@@ -1485,10 +1498,10 @@ void drumkv1_impl::process_midi ( uint8_t *data, uint32_t size )
 				// generate
 				pv->gen1.start();
 				// frequencies
-				const float freq1 = float(key)
-					+ *elem->gen1.coarse * COARSE_SCALE
+				const float tuning1
+					= *elem->gen1.coarse * COARSE_SCALE
 					+ *elem->gen1.fine * FINE_SCALE;
-				pv->gen1_freq = drumkv1_freq(freq1);
+				pv->gen1_freq = m_freqs[key] * drumkv1_freq2(tuning1);
 				// filters
 				const int type1 = int(*elem->dcf1.type);
 				pv->dcf11.reset(drumkv1_filter1::Type(type1));
@@ -1720,6 +1733,31 @@ drumkv1_programs *drumkv1_impl::programs (void)
 }
 
 
+// Micro-tuning support
+void drumkv1_impl::updateTuning (void)
+{
+
+	if (m_config.bTuningEnabled) {
+		// Custom micro-tuning, possibly from Scala keymap and scale files...
+		drumkv1_tuning tuning(
+			m_config.fTuningRefPitch,
+			m_config.iTuningRefNote);
+		if (!m_config.sTuningKeyMapFile.isEmpty())
+			tuning.loadKeyMapFile(m_config.sTuningKeyMapFile);
+		if (!m_config.sTuningScaleFile.isEmpty())
+			tuning.loadScaleFile(m_config.sTuningScaleFile);
+		for (int note = 0; note < MAX_NOTES; ++note)
+			m_freqs[note] = tuning.noteToPitch(note);
+		// Done custom tuning.
+	} else {
+		// Native tuning, 12-tone equal temperament western standard...
+		for (int note = 0; note < MAX_NOTES; ++note)
+			m_freqs[note] = drumkv1_freq(note);
+		// Done native tuning.
+	}
+}
+
+
 // all reset clear
 
 void drumkv1_impl::reset (void)
@@ -2431,5 +2469,12 @@ void drumkv1::directNoteOn ( int note, int vel )
 }
 
 
+// Micro-tuning support
+void drumkv1::updateTuning (void)
+{
+	m_pImpl->updateTuning();
+}
+
+
 // end of drumkv1.cpp
 
