@@ -1,7 +1,7 @@
 // drumkv1_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -327,6 +327,17 @@ void drumkv1_config::load (void)
 	QSettings::beginGroup("/Custom");
 	sCustomStyleTheme = QSettings::value("/StyleTheme").toString();
 	QSettings::endGroup();
+
+	// Micro-tuning options.
+	QSettings::beginGroup("/Tuning");
+	bTuningEnabled = QSettings::value("/Enabled", false).toBool();
+	fTuningRefPitch = float(QSettings::value("/RefPitch", 440.0).toDouble());
+	iTuningRefNote = QSettings::value("/RefNote", 69).toInt();
+	sTuningScaleDir = QSettings::value("/ScaleDir").toString();
+	sTuningScaleFile = QSettings::value("/ScaleFile").toString();
+	sTuningKeyMapDir = QSettings::value("/KeyMapDir").toString();
+	sTuningKeyMapFile = QSettings::value("/KeyMapFile").toString();
+	QSettings::endGroup();
 }
 
 
@@ -356,6 +367,17 @@ void drumkv1_config::save (void)
 	QSettings::setValue("/StyleTheme", sCustomStyleTheme);
 	QSettings::endGroup();
 
+	// Micro-tuning options.
+	QSettings::beginGroup("/Tuning");
+	QSettings::setValue("/Enabled", bTuningEnabled);
+	QSettings::setValue("/RefPitch", double(fTuningRefPitch));
+	QSettings::setValue("/RefNote", iTuningRefNote);
+	QSettings::setValue("/ScaleDir", sTuningScaleDir);
+	QSettings::setValue("/ScaleFile", sTuningScaleFile);
+	QSettings::setValue("/KeyMapDir", sTuningKeyMapDir);
+	QSettings::setValue("/KeyMapFile", sTuningKeyMapFile);
+	QSettings::endGroup();
+
 	QSettings::sync();
 }
 
