@@ -1,7 +1,7 @@
 // drumkv1_config.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -27,8 +27,8 @@
 #define DRUMKV1_TITLE       PACKAGE_NAME
 
 #define DRUMKV1_SUBTITLE    "an old-school drum-kit sampler."
-#define DRUMKV1_WEBSITE     "http://drumkv1.sourceforge.net"
-#define DRUMKV1_COPYRIGHT   "Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved."
+#define DRUMKV1_WEBSITE     "https://drumkv1.sourceforge.io"
+#define DRUMKV1_COPYRIGHT   "Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved."
 
 #define DRUMKV1_DOMAIN      "rncbc.org"
 
@@ -78,6 +78,15 @@ public:
 	// Whether to display GM Standard drum-note/key names.
 	bool bUseGMDrumNames;
 
+	// Micro-tuning options.
+	bool    bTuningEnabled;
+	float   fTuningRefPitch;
+	int     iTuningRefNote;
+	QString sTuningScaleDir;
+	QString sTuningScaleFile;
+	QString sTuningKeyMapDir;
+	QString sTuningKeyMapFile;
+
 	// Singleton instance accessor.
 	static drumkv1_config *getInstance();
 
