@@ -1,7 +1,7 @@
 // drumkv1_param.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -135,6 +135,25 @@ float drumkv1_param::paramDefaultValue ( drumkv1::ParamIndex index )
 }
 
 
+float drumkv1_param::paramSafeValue ( drumkv1::ParamIndex index, float fValue )
+{
+	const ParamInfo& param = drumkv1_params[index];
+
+	if (param.type == PARAM_BOOL)
+		return (fValue > 0.5f ? 1.0f : 0.0f);
+
+	if (fValue < param.min)
+		return param.min;
+	if (fValue > param.max)
+		return param.max;
+
+	if (param.type == PARAM_INT)
+		return ::rintf(fValue);
+	else
+		return fValue;
+}
+
+
 float drumkv1_param::paramValue ( drumkv1::ParamIndex index, float fScale )
 {
 	const ParamInfo& param = drumkv1_params[index];
@@ -204,9 +223,11 @@ void drumkv1_param::loadElements (
 					continue;
 				if (eChild.tagName() == "sample") {
 				//	int index = eChild.attribute("index").toInt();
-					const QString& sFilename = eChild.text();
+					QFileInfo fi(eChild.text());
+					if (fi.isSymLink())
+						fi.setFile(fi.symLinkTarget());
 					element->setSampleFile(
-						mapPath.absolutePath(sFilename).toUtf8().constData());
+						mapPath.absolutePath(fi.filePath()).toUtf8().constData());
 				}
 				else
 				if (eChild.tagName() == "params") {
@@ -222,7 +243,9 @@ void drumkv1_param::loadElements (
 							const QString& sName = eParam.attribute("name");
 							if (!sName.isEmpty() && s_hash.contains(sName))
 								index = s_hash.value(sName);
-							const float fValue = eParam.text().toFloat();
+							const float fValue
+								= drumkv1_param::paramSafeValue(index,
+									eParam.text().toFloat());
 							element->setParamValue(index, fValue, 0);
 							element->setParamValue(index, fValue);
 						}
@@ -249,7 +272,7 @@ void drumkv1_param::saveElements (
 		if (pszSampleFile == NULL)
 			continue;
 		QFileInfo fi(QString::fromUtf8(pszSampleFile));
-		if (bSymLink) {
+		if (bSymLink && fi.absolutePath() != QDir::current().absolutePath()) {
 			const QString& sPath = fi.absoluteFilePath();
 			const QString& sName = fi.baseName();
 			const QString& sExt  = fi.completeSuffix();
@@ -259,6 +282,7 @@ void drumkv1_param::saveElements (
 			QFile(sPath).link(sLink);
 			fi.setFile(QDir::current(), sLink);
 		}
+		else if (fi.isSymLink()) fi.setFile(fi.symLinkTarget());
 		QDomElement eElement = doc.createElement("element");
 		eElement.setAttribute("index", QString::number(note));
 	//	eElement.setAttribute("name", noteName(note));
@@ -375,7 +399,8 @@ bool drumkv1_param::loadPreset (
 								index = s_hash.value(sName);
 							}
 							const float fValue = eParam.text().toFloat();
-							pDrumk->setParamValue(index, fValue);
+							pDrumk->setParamValue(index,
+								drumkv1_param::paramSafeValue(index, fValue));
 						}
 					}
 				}
