@@ -1,7 +1,7 @@
 // drumkv1_ui.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -177,4 +177,19 @@ void drumkv1_ui::directNoteOn ( int note, int vel )
 }
 
 
+void drumkv1_ui::updateTuning (void)
+{
+	m_pDrumk->updateTuning();
+}
+
+
+// MIDI note/octave name helper (static).
+QString drumkv1_ui::noteName ( int note )
+{
+	static const char *notes[] =
+		{ "C", "C#", "D", "D#", "E", "F", "F#", "G", "G#", "A", "A#", "B" };
+	return QString("%1 %2").arg(notes[note % 12]).arg((note / 12) - 1);
+}
+
+
 // end of drumkv1_ui.cpp
