@@ -1,7 +1,7 @@
 // drumkv1_ui.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2018, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -77,6 +77,11 @@ public:
 
 	void directNoteOn(int note, int vel);
 
+	void updateTuning();
+
+	// MIDI note/octave name helper.
+	static QString noteName(int note);
+
 private:
 
 	drumkv1 *m_pDrumk;
